import { SERVER_CONF, WEB_API_CONF, APP_API_CONF } from './config/env.config.js'
import proxyConfig from './config/proxy.config.js'
// import hooks from './hooks'
import webInfo from './config/webInfo.js'

export default {
    server: {
        host: SERVER_CONF.HOSTNAME,
        port: SERVER_CONF.PORT
    },

    // env: {
    //     nodeenv: process.env.NODE_ENV,
    //     ...WEB_API_CONF
    // },

    privateRuntimeConfig: {
        axios: {
            baseURL: WEB_API_CONF.API_LOCAL_URL || WEB_API_CONF.BASE_URL
        },
        WEB_API_CONF,
        APP_API_CONF,
        ENV_MODE: process.env.ENV_MODE
    },

    publicRuntimeConfig: {
        axios: {
            browserBaseURL: WEB_API_CONF.BASE_URL_BROWSER
        },
        WEB_API_CONF,
        APP_API_CONF,
        ENV_MODE: process.env.ENV_MODE
    },

    // Global page headers (https://go.nuxtjs.dev/config-head)
    head: {
        title: webInfo.title,
        titleTemplate: `%s-${webInfo.slogan}`,
        meta: [
            { charset: 'utf-8' },
            {
                name: 'viewport',
                content: 'width=device-width, initial-scale=1,user-scalable=no'
            },
            // { 'http-equiv': 'Content-Security-Policy', content: 'upgrade-insecure-requests' },
            {
                hid: 'description',
                name: 'description',
                content: webInfo.description
            }
        ],
        link: [{ rel: 'icon', type: 'image/x-icon', href: 'favicon.ico' }],
        script: [
            { src: 'scripts/flexible.js' },
            { src: '//res.wx.qq.com/open/js/jweixin-1.4.0.js' },
            {
                src: '//at.alicdn.com/t/font_1909239_s4u6l1v1ysn.js',
                async: true,
                rel: 'preload'
            }, // 平台 icon
            {
                src: '//at.alicdn.com/t/font_2037105_pnqqt3hxv5j.js',
                async: true,
                rel: 'preload'
            } // 视频办公宝 icon
        ]
    },

    // Global CSS (https://go.nuxtjs.dev/config-css)
    css: [
        '@/assets/styles/reset.scss'
        // 'swiper/dist/css/swiper.min.css'
        // 'ant-design-vue/dist/antd.css'
    ],

    // Plugins to run before rendering page (https://go.nuxtjs.dev/config-plugins)
    plugins: [
        '~/plugins/inject-demo',
        '~/plugins/inject-api',
        '~/plugins/inject-utils',
        { src: '~/plugins/vue-bus' },
        '~/plugins/axios/index.js',
        // '~/plugins/axios/index.bak.js',
        '~/plugins/nuxt-client-init.client.js'
    ],

    // Auto import components (https://go.nuxtjs.dev/config-components)
    components: true,

    // Modules for dev and build (recommended) (https://go.nuxtjs.dev/config-modules)
    buildModules: [
        // https://go.nuxtjs.dev/eslint
        '@nuxtjs/eslint-module',
        '@nuxtjs/style-resources',
        // https://go.nuxtjs.dev/stylelint
        // ['@nuxtjs/stylelint-module',{}]
        '@nuxtjs/stylelint-module'
    ],

    // Modules (https://go.nuxtjs.dev/config-modules)
    modules: [
        // https://go.nuxtjs.dev/axios
        '@nuxtjs/axios',
        // https://dayjs.gitee.io/
        '@nuxtjs/dayjs',
        // https://go.nuxtjs.dev/pwa
        '@nuxtjs/pwa',
        '@nuxtjs/toast'
        // https://go.nuxtjs.dev/content
        // '@nuxt/content'
    ],

    eslint: {
        fix: true
    },

    stylelint: {
        fix: true
    },

    /** 注意，这里只能引入样式的variables, mixins, functions文件，不能引入实际样式！ */
    styleResources: {
        scss: [
            // './assets/styles/variables.scss', // 全局 scss 变量
            './assets/styles/mixins.scss' // 全局 scss 混合
        ]
    },

    axios: {
        // host: '',
        // port: '',
        // prefix: '/', // Default: "/"
        // baseURL: 'https://beta.laihua.com/webapi', // Default: http://[HOST]:[PORT][PREFIX]
        // browserBaseURL: '/webapi',
        proxy: true,
        credentials: true
    },

    proxy: proxyConfig,

    dayjs: {
        locales: ['zh-cn', 'en'],
        defaultLocale: 'zh-cn'
    },

    toast: {
        position: 'top-center',
        duration: 2000
    },

    buildDir: '.nuxt',

    extendPlugins (plugins) {
        // if (process.env.ENV_MODE === 'pro') {
        //     return plugins
        // }
    },

    // Build Configuration (https://go.nuxtjs.dev/config-build)
    build: {
        // analyze: {
        //     analyzerMode: 'static'
        // },

        publicPath: '/_nuxt/',

        extractCSS: {
            ignoreOrder: true
            // allChunks: true,
        },
        extend (config, ctx) {
            const { isDev, isClient } = ctx
            if (isClient && process.env.ENV_MODE === 'pro') {
                config.optimization.minimizer[0].options.terserOptions.compress.drop_console = true
            }
            // console.log('config信息===>:', config)
            // console.log('config.module.rules==>:', config.module.rules)
        }
    },
    // 配置loader
    loaders: {
        // sass: {
        //     implementation: require("sass")
        // },
        // scss: {
        //     implementation: require("sass")
        // },
        // imgUrl: {
        //     limit: 3 * 1024,
        // },
        // vue: {
        //     transformAssetUrls: {
        //         video: ["src", "poster"],
        //         source: "src",
        //     }
        // },
        less: {
            lessOptions: {
                javascriptEnabled: true
            }
        }
    },
    router: {
        // base: '/',
        // middleware: ['route-chagne']
    },

    // performance: {
    //     hints: false,
    //     prefetch: false,
    //     maxEntrypointSize: 1024 * 1024,
    //     maxAssetSize: 1024 * 960,
    // },

    // hooks: hooks(this),

    render: {
        static: {
            prefix: true
        }
    },

    // Content module configuration (https://go.nuxtjs.dev/config-content)
    content: {}
}
