// eslint-disable-next-line
/* eslint-disable */

import axios from 'axios'
import utils from 'axios/lib/utils'
// import setConfig from '@/plugins/axios/axios.setConfig.js'
import handleResponse from '@/plugins/axios/axios.handleResponse.js'
import handleError from '@/plugins/axios/axios.handleError.js'

const { Cancel } = axios
const pendingPool = new Map()

export default function (context, inject) {
    const { $axios, $config, store, req } = context
    const xRealIp = store.getters['x-real-ip']

    const intactAxios = $axios.create({})
    intactAxios.interceptors.request.use((config) => {
        config.headers.common['x-real-ip'] = xRealIp
        return config
    })

    const { APP_API_CONF } = $config
    const appAxios = $axios.create({})
    const appBaseURL = process.server
        ? APP_API_CONF.API_LOCAL_URL || APP_API_CONF.BASE_URL
        : APP_API_CONF.BASE_URL_BROWSER
    appAxios.setBaseURL(appBaseURL)

    appAxios.interceptors.request.use((config) => {
        config.headers.common['x-real-ip'] = xRealIp
        return config
    })

    /**
     * 请求拦截
     */
    const requestInterceptorId = $axios.interceptors.request.use(
        (config) => {
            $axios.config = Object.assign({}, config)
            // $axios.setHeader('x-real-ip', 11111)
            config.headers.common['x-real-ip'] = xRealIp
            config.cancelToken = new $axios.CancelToken((cancelFn) => {
                pendingPool.has(config.url)
                    ? cancelFn(`${config.url}请求重复`)
                    : pendingPool.set(config.url, {
                          cancelFn,
                          global: config.global,
                      })
            })
            return config
        },
        (err) => {
            return Promise.reject(err)
        }
    )
    /**
     * 响应拦截
     */
    const responseInterceptorId = $axios.interceptors.response.use(
        (response) => {
            const { config } = response
            pendingPool.delete(config.url)

            return Promise.resolve(handleResponse(response))
        },
        // 对异常响应处理
        (err) => {
            const { config } = $axios
            if (!$axios.isCancel(err)) pendingPool.delete(config.url)

            if (!err) return Promise.reject(err)

            if (err.response) {
                err = handleError(err)
            }
            // 没有response(没有状态码)的情况
            // eg: 超时；断网；请求重复被取消；主动取消请求；
            else {
                if ($axios.isCancel(err)) {
                    throw new Cancel(
                        err.message || `请求'${$axios.config.url}'被取消`
                    )
                } else if (err.stack && err.stack.includes('timeout')) {
                    err.message = '请求超时!'
                } else {
                    err.message = '连接服务器失败!'
                }
            }

            return Promise.reject(err)
        }
    )
    // $axios.onError((error) => {
    //     throw new Error('xxx1212')
    //     // return {}
    //     // return { error, data: {} }
    // })

    // 移除全局的请求拦截器
    function removeRequestInterceptor() {
        $axios.interceptors.request.eject(requestInterceptorId)
    }

    // 移除全局的响应拦截器
    function removeResponseInterceptor() {
        $axios.interceptors.response.eject(responseInterceptorId)
    }

    /**
     * 清除所有pending状态的请求
     * @param {Array} whiteList 白名单，里面的请求不会被取消
     * 返回值 被取消了的api请求
     */
    function clearPendingPool(whiteList = []) {
        if (!pendingPool.size) return

        // const pendingUrlList = [...pendingPool.keys()].filter((url) => !whiteList.includes(url))
        const pendingUrlList = Array.from(pendingPool.keys()).filter(
            (url) => !whiteList.includes(url)
        )
        if (!pendingUrlList.length) return

        pendingUrlList.forEach((pendingUrl) => {
            // 清除掉所有非全局的pending状态下的请求
            if (!pendingPool.get(pendingUrl).global) {
                pendingPool.get(pendingUrl).cancelFn()
                pendingPool.delete(pendingUrl)
            }
        })

        return pendingUrlList
    }

    $axios.removeRequestInterceptor = removeRequestInterceptor
    $axios.removeResponseInterceptor = removeResponseInterceptor
    $axios.clearPendingPool = clearPendingPool

    inject('intactAxios', intactAxios)
    inject('appAxios', appAxios)
}
