export const state = () => ({
    counter: 0,
    lowerLetter: 'lower',
    supportWebp: false, // 是否支持webp图片
    userAgent: '', // userAgent信息
    reqHeaders: {},
    apiPrefix: ''
})

export const getters = {
    lowerToUpper: (state) => {
        return state.lowerLetter.toUpperCase()
    },
    'x-real-ip': state => state.reqHeaders['x-real-ip'] || 'xxxxx'
}

export const mutations = {
    // 检查是否支持webp格式的图片
    checkWebp (state) {
        const { isIos } = this.$utils.judgeUserAgent(navigator.userAgent || '')
        if (process.server || isIos) {
            return
        }

        try {
            const isWebp = this.$utils.checkWebpAvailable()
            state.supportWebp = isWebp
            // state.assetsDir = 'assets/imgWebp'
            // state.webpSuffix = '.webp'
            window.supportWebp = isWebp
            document.cookie = `supportWebp=${isWebp}`
            document.documentElement.className += 'webp-available'
        } catch (error) {
            console.log('error:', error)
        }
    },
    setUserAgent (state, userAgent) {
        state.userAgent = {
            info: userAgent,
            ...this.$utils.judgeUserAgent(userAgent)
        }
    },
    saveRequestHeaders (state, payload) {
        const { req } = payload
        if (!req) {
            return
        }
        state.reqHeaders = req.headers
    },
    /**
     * 保存api前缀
     */
    setApiPrefix (state) {
        try {
            state.apiPrefix = this.$config.WEB_API_CONF.BASE_URL_BROWSER
        } catch (error) {
            console.log('error:', error)
        }
    }
}

export const actions = {
    nuxtServerInit ({ commit }, context) {
        console.log('server init====>:')
        // 保存设备信息
        const ua = process.server
            ? context.req.headers['user-agent']
            : navigator.userAgent
        commit('setUserAgent', ua)

        // 保存用户真实ip
        commit('saveRequestHeaders', { req: context.req })

        commit('setApiPrefix')

        // if (req.session && req.session.authUser) {
        //     commit('SET_USER', req.session.authUser)
        // }
    },
    async nuxtClientInit (store, context) {
        console.log('client init====>:')
        // eslint-disable-next-line
        const { getters, dispatch, commit } = store

        await commit('checkWebp')
    }
}
