let time
const util = {
    /**
     * 处理所有非本地的资源链接，返回为七牛云地址
     * @param {String} url 资源链接
     */
    handleAssetsUrl (url) {
        if (!url) {
            return
        }

        const httpReg = /^http/
        const reg = /^\//
        const slashHttpReg = /^\/http/
        const qiniuAssetsUrl = 'https://resources.laihua.com'

        if (httpReg.test(url) || url.includes('base64')) {
            // 兼容第三方登录的头像地址为http的情况，替换为https
            return url.replace(/http:/, 'https:')
        }
        // 兼容以/开头的绝对路径：/http://xxxxx.com
        if (slashHttpReg.test(url)) {
            return url.substr(1)
        } else if (reg.test(url)) {
            return qiniuAssetsUrl + url
        } else {
            return qiniuAssetsUrl + '/' + url
        }
    },
    /**
     * 检测浏览器是否支持webp
     */
    checkWebpAvailable: () => {
        try {
            return document
                .createElement('canvas')
                .toDataURL('image/webp')
                .includes('data:image/webp')
        } catch (error) {
            return false
        }
    },
    /**
     * 判断设备
     * @param {*} ua
     */
    judgeUserAgent: (ua) => {
        ua =
            ua ||
            (window
                ? window.navigator.userAgent
                : '非浏览器环境,无法自动判断请传入userAgent')
        return {
            trident: ua.includes('Trident'), // IE内核
            presto: ua.includes('Presto'), // opera内核
            Alipay: ua.includes('Alipay'), // 支付宝
            webKit: ua.includes('AppleWebKit'), // 苹果、谷歌内核
            gecko: ua.includes('Gecko') && !ua.includes('KHTML'), // 火狐内核
            mobile: !!ua.match(/AppleWebKit.*Mobile.*/), // 是否为移动终端
            ios: !!ua.match(/\(i[^;]+;( U;)? CPU.+Mac OS X/), // ios终端
            android: ua.includes('Android') || ua.includes('Linux'), // android终端或者uc浏览器
            iPhone: ua.includes('iPhone') || ua.includes('Mac'), // 是否为iPhone或者安卓QQ浏览器
            // iPhone: ua.match(/iphone|ipod|ipad/),//
            iPad: ua.includes('iPad'), // 是否为iPad
            webApp: !ua.includes('Safari'), // 是否为web应用程序，没有头部与底部
            weixin: ua.includes('MicroMessenger'), // 是否为微信浏览器
            qq: ua.match(/\sQQ/i) !== null, // 是否QQ
            Safari: ua.includes('Safari'), // Safari浏览器,
            weibo: ua.includes('Weibo'), // 是否微博
            isEdge: ua.includes('Edge'),
            isWxwork: ua.includes('wxwork'), // 企业微信浏览器
            isFF: ua.includes('Firefox'),
            isOpera: ua.includes('Opera'),
            isBB: ua.includes('BlackBerry'),
            isChrome: ua.includes('Chrome'),
            isMaxthon: ua.includes('Maxthon'),
            isIos: /(iPhone|iPad|iPod|iOS)/i.test(ua),
            isIE: ['compatible', 'MSIE'].every(n => ua.includes(n)),
            isSafari: ua.includes('Safari') && !ua.includes('Chrome'),
            isMobile: /(iPhone|iPad|iPod|iOS|Opera Mini|Android.*Mobile|NetFront|PSP|BlackBerry|Windows Phone|micromessenger)/gi.test(
                ua
            ),
            isLhAndroid: ua.includes('os=Android'),
            isLhIos: ua.includes('os=ios'),
            isLhApp: ua.includes('os=Android') || ua.includes('os=ios')
        }
    },
    /**
     * 正则匹配
     */
    reg: {
        /**
         *
         * @param {Number} idChinese 15及18位长度大陆身份证校验
         */
        idChinese (id) {
            const reg = /(^[1-9]\d{5}(18|19|([23]\d))\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\d{3}[0-9Xx])|([1−9]\d5\d2((0[1−9])|(10|11|12))(([0−2][1−9])|10|20|30|31)\d2[0−9Xx])|([1−9]\d5\d2((0[1−9])|(10|11|12))(([0−2][1−9])|10|20|30|31)\d2[0−9Xx])/
            return reg.test(id)
        },
        /**
         *
         * @param {Number} idHk 8位长度香港身份证校验
         */
        idHK (id) {
            const reg = /[A-Z]{1,2}[0-9]{6}([0-9A])/
            return reg.test(id)
        },
        /**
         *
         * @param {Number} phone 手机号码校验
         */
        phone (phone) {
            const reg = /^(0|86|17951|12593)?1[3|4|5|6|7|8|9][0-9]{5,9}$/
            return reg.test(phone)
        }
    },
    /**
     * 微信分享
     * @param {*} option
     */
    shareWx (option) {
        clearTimeout(time)
        // 防止重复
        time = setTimeout(() => {
            const shareUrl =
                option && option.url ? option.url : window.location.href
            const shareTitle =
                option && option.title
                    ? option.title
                    : '来画-短视频智能创作营销平台-MG动画制作工具-来画视频'
            const shareDesc =
                option && option.desc
                    ? option.desc
                    : '做短视频像做PPT一样简单？快挪步到“来画视频”一探究竟吧！'
            const sharePic =
                option && option.pic
                    ? option.pic
                    : 'https://resources.laihua.com/2018-11-15/1650326b-0fc4-4c65-9ea8-14f09b08d26d.png'
            // config信息验证后会执行ready方法，所有接口调用都必须在config接口获得结果之后，
            // config是一个客户端的异步操作，所以如果需要在页面加载时就调用相关接口，
            // 则须把相关接口放在ready函数中调用来确保正确执行。对于用户触发时才调用的接口，
            // 则可以直接调用，不需要放在ready函数中。
            // eslint-disable-next-line
            wx.updateAppMessageShareData({
                title: shareTitle, // 分享标题
                desc: shareDesc, // 分享描述
                link: shareUrl, // 分享链接，该链接域名或路径必须与当前页面对应的公众号JS安全域名一致
                imgUrl: sharePic, // 分享图标
                success () {
                    // 设置成功
                }
            })
            // eslint-disable-next-line
            wx.updateTimelineShareData({
                title: shareTitle, // 分享标题
                link: shareUrl, // 分享链接，该链接域名或路径必须与当前页面对应的公众号JS安全域名一致
                imgUrl: sharePic, // 分享图标
                success () {
                    // 设置成功
                }
            })
            // eslint-disable-next-line
            wx.onMenuShareTimeline({
                title: shareTitle, // 分享标题
                desc: shareDesc, // 分享描述
                link: shareUrl, // 分享链接
                imgUrl: sharePic // 分享图标
            })
            // 分享给好友
            // eslint-disable-next-line
            wx.onMenuShareAppMessage({
                title: shareTitle, // 分享标题
                desc: shareDesc, // 分享描述
                link: shareUrl, // 分享链接
                imgUrl: sharePic, // 分享图标
                type: '' // 分享类型,music、video或link，不填默认为link
            })
            // 分享到qq
            // eslint-disable-next-line
            wx.onMenuShareQQ({
                title: shareTitle, // 分享标题
                desc: shareDesc, // 分享描述
                link: shareUrl, // 分享链接
                imgUrl: sharePic // 分享图标
            })
            // 分享到qq空间
            // eslint-disable-next-line
            wx.onMenuShareQZone({
                title: shareTitle, // 分享标题
                desc: shareDesc, // 分享描述
                link: shareUrl, // 分享链接
                imgUrl: sharePic // 分享图标
            })
        }, 500)
    },
    /**
     * 根据指定属性名的值，按照升序排序
     */
    sortList (propertyName) {
        return function (object1, object2) {
            const value1 = parseFloat(object1[propertyName])
            const value2 = parseFloat(object2[propertyName])
            if (value1 < value2) {
                return -1
            } else if (value1 > value2) {
                return 1
            } else {
                return 0
            }
        }
    },
    /**
     * 时间格式化
     * @param {*} times 可以为秒或者毫秒，必填
     * @param {*} formatStr 返回时间格式 非必填
     */
    formatDate (times, formatStr) {
        let timestamp
        if (/^\d{12,14}$/.test(times)) {
            timestamp = times
        } else if (/^\d{9,11}$/.test(times)) {
            timestamp = times * 1000
        } else {
            return times
        }
        let format = formatStr || 'yyyy/MM/dd'
        const currentDate = new Date(parseInt(timestamp))
        const date = {
            'M+': currentDate.getMonth() + 1,
            'd+': currentDate.getDate(),
            'h+': currentDate.getHours(),
            'm+': currentDate.getMinutes(),
            's+': currentDate.getSeconds()
        }
        if (/(y+)/i.test(format)) {
            format = format.replace(
                RegExp.$1,
                (currentDate.getFullYear() + '').substr(4 - RegExp.$1.length)
            )
        }
        for (const k in date) {
            if (new RegExp('(' + k + ')').test(format)) {
                format = format.replace(
                    RegExp.$1,
                    RegExp.$1.length === 1
                        ? date[k]
                        : ('00' + date[k]).substr(('' + date[k]).length)
                )
            }
        }
        return format
    },

    /**
     * 秒转化为分钟格式
     */
    secToMin (secs) {
        return [
            // parseInt(secs / 60 / 60),
            parseInt((secs / 60) % 60),
            parseInt(secs % 60)
        ]
            .join(':')
            .replace(/\b(\d)\b/g, '0$1')
    },
    /**
     * 处理时区转换
     * @param {*} UTCDateString 时区字符串
     */
    convertUTCTimeToLocalTime (UTCDateString) {
        if (!UTCDateString) {
            return '-'
        }
        function formatFunc (str) {
            // 格式化显示
            return str > 9 ? str : '0' + str
        }
        const date2 = new Date(UTCDateString) // 这步是关键
        const year = date2.getFullYear()
        const mon = formatFunc(date2.getMonth() + 1)
        const day = formatFunc(date2.getDate())
        let hour = date2.getHours()
        hour = formatFunc(hour)
        const min = formatFunc(date2.getMinutes())
        const dateStr = year + '/' + mon + '/' + day + ' ' + hour + ':' + min
        return dateStr
    },
    /**
     * 是否在来画app内
     */
    ifLaihua () {
        let lhAndroid = false
        let lhIOS = false
        // 是否在安卓来画中
        lhAndroid = !!navigator.userAgent.includes('os=Android')
        // 是否在ios来画中
        lhIOS = !!navigator.userAgent.includes('os=ios')

        return lhAndroid || lhIOS
    },
    /**
     * 生成uuid
     */
    generateUuid () {
        return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(
            /[xy]/g,
            function (c) {
                const r = (Math.random() * 16) | 0
                const v = c === 'x' ? r : (r & 0x3) | 0x8
                return v.toString(16)
            }
        )
    }
}

export const {
    checkWebpAvailable,
    judgeUserAgent,
    sortList,
    formatDate,
    secToMin,
    convertUTCTimeToLocalTime,
    ifLaihua,
    generateUuid
} = util
export default util
